@@ -17,7 +17,7 @@ logger = logging.getLogger()
 class ActorExecutorException(Exception):
     pass
 
-def actor_executor(bucket: str, prefix: str, conf_filename: str, execution_func, finally_func = None, executor_trigger_message_str: str = None):
+def actor_executor(bucket: str, prefix: str, actor_conf_file: str, execution_func, success_func = None, failed_func = None, executor_trigger_message_str: str = None):
     """[summary]
 
     Args:
@@ -27,7 +27,7 @@ def actor_executor(bucket: str, prefix: str, conf_filename: str, execution_func,
     """
     # init
     s3_client = boto3.client('s3')
-    actor_conf = ActorConf.get_actor_conf(s3_client=s3_client, bucket=bucket, prefix=prefix, conf_filename=conf_filename)
+    actor_conf = ActorConf.get_actor_conf(s3_client=s3_client, bucket=bucket, prefix=prefix, actor_conf_file=actor_conf_file)
     logger.info(f"actor_conf: {actor_conf}")
 
     # sqs init
@@ -73,22 +73,23 @@ def actor_executor(bucket: str, prefix: str, conf_filename: str, execution_func,
             executor_result_status = ExecutorResultStatusType.SUCCESS
         except Exception as e:
             # when the task failed, retry
+            error_message = str(e)
             stack_trace = traceback.format_exc().replace("\n", " ")
             retry_count = executor_task_message.retry_count + 1
             if retry_count > actor_conf.max_retry:
-                result = str(e)
                 executor_result_status = ExecutorResultStatusType.FAILED
-                logger.error(f'actor_executor is failed, {executor_task_message},{e},{stack_trace}')
+                logger.error(f'actor_executor is failed, {executor_task_message},{error_message},{stack_trace}')
             else:
                 executor_result_status = ExecutorResultStatusType.FAILED
                 retry_executor_task_message = ExecutorTaskMessage(
                     message=executor_task_message.message,
                     retry_count=retry_count,
+                    task_groupid=executor_task_message.task_groupid,
                     driver_start_timestamp=executor_task_message.driver_start_timestamp
                 )
                 retry_message = ExecutorTaskMessage.encode(retry_executor_task_message)
-                send_executor_task_message(executor_task_q, [retry_message], executor_key=actor_conf.executor_key)
-                logger.error(f'actor_executor is retried, {retry_executor_task_message}, {e}, {stack_trace}')
+                send_executor_task_message(queue=executor_task_q, message_body_list=[retry_message], task_groupid=executor_trigger_message.task_groupid)
+                logger.warning(f'actor_executor is retried, {retry_executor_task_message}, {error_message}, {stack_trace}')
 
         # timer
         task_end = time.time()
@@ -101,9 +102,10 @@ def actor_executor(bucket: str, prefix: str, conf_filename: str, execution_func,
                 status = executor_result_status,
                 result = result,
                 driver_start_timestamp = executor_task_message.driver_start_timestamp,
-                executor_start_timestamp = executor_trigger_message.executor_trigger_timestamp,
+                executor_start_timestamp = executor_trigger_message.executor_start_timestamp,
                 retry_count = executor_task_message.retry_count,
-                executor_id = executor_trigger_message.executor_id,
+                trigger_groupid = executor_trigger_message.trigger_groupid,
+                task_groupid = executor_trigger_message.task_groupid,
                 execute_time = task_time,
                 timestamp = datetime.now().strftime('%Y%m%d%H%M%S')
             )
@@ -115,27 +117,41 @@ def actor_executor(bucket: str, prefix: str, conf_filename: str, execution_func,
             logger.debug(executed_time)
 
     # run own func
-    if finally_func:
-        finally_func(executor_result_list)
+    #
+    success_list = list(filter(lambda x: x.status != ExecutorResultStatusType.FAILED, executor_result_list))
+    failed_list = list(filter(lambda x: x.status == ExecutorResultStatusType.FAILED, executor_result_list))
+    
+    if success_func:
+        if len(success_list) > 0:
+            success_func(success_list)
+        else:
+            logger.info("success_list is zero")
+    if failed_func:
+        if len(failed_list) > 0:
+            failed_func(failed_list)
+        else:
+            logger.info("failed_list is zero")
 
     # send finish message
     if driver_trigger_status == DriverTriggerStatusType.CONTINUE:
         retrun_driver_trigger_message = DriverTriggerMessage(
                 status=DriverTriggerStatusType.CONTINUE,
-                message=f"executor_id was {executor_trigger_message.executor_id}",
-                executor_id=executor_trigger_message.executor_id,
-                driver_trigger_timestamp = timestamp()
+                message=f"trigger_groupid was {executor_trigger_message.trigger_groupid}",
+                trigger_groupid = executor_trigger_message.trigger_groupid,
+                task_groupid = executor_trigger_message.task_groupid,
+                driver_start_timestamp = timestamp()
         )
     elif driver_trigger_status == DriverTriggerStatusType.FINISH:
         retrun_driver_trigger_message = DriverTriggerMessage(
                 status=DriverTriggerStatusType.FINISH,
-                message=f"executor_id was {executor_trigger_message.executor_id}",
-                executor_id=executor_trigger_message.executor_id,
-                driver_trigger_timestamp = timestamp()
+                message=f"trigger_groupid was {executor_trigger_message.trigger_groupid}",
+                trigger_groupid = executor_trigger_message.trigger_groupid,
+                task_groupid = executor_trigger_message.task_groupid,
+                driver_start_timestamp = timestamp()
         )
     else:
         raise ActorExecutorException("illegal driger status type")
     
-    send_driver_trigger_message(queue=driver_trigger_q, message_body=retrun_driver_trigger_message.encode(), executor_id=executor_trigger_message.executor_id, executor_key=actor_conf.executor_key)
+    send_driver_trigger_message(queue=driver_trigger_q, message_body=retrun_driver_trigger_message.encode(), trigger_groupid=executor_trigger_message.trigger_groupid)
 
     
\ No newline at end of file
