@@ -16,8 +16,9 @@ class DriverTriggerMessage:
     """
     status: DriverTriggerStatusType
     message: str
-    executor_id: str
-    driver_trigger_timestamp: str
+    trigger_groupid: str
+    task_groupid: str
+    driver_start_timestamp: str
 
     @classmethod
     def decode(cls, message_str: str):
@@ -50,9 +51,9 @@ class ExecutorTriggerMessage:
     """
     status: ExecutorTriggerStatusType
     message: str
-    driver_trigger_timestamp: str
-    executor_id: int
-    executor_trigger_timestamp: str
+    trigger_groupid: str
+    task_groupid: str
+    executor_start_timestamp: str
 
     @classmethod
     def decode(cls, message_str: str):
@@ -73,15 +74,16 @@ class ExecutorTriggerMessage:
             str: [description]
         """
         return self.to_json(indent=4, ensure_ascii=False)
-        #return f"{self.status.value},{self.message},{self.driver_trigger_timestamp},{self.executor_id},{self.executor_trigger_timestamp}"
-
+        
 @dataclass_json
 @dataclass
 class ExecutorTaskMessage:
     """[summary]
     """
     message: str
+    trigger_groupid: str
     retry_count: int
+    task_groupid: str
     driver_start_timestamp: str
     
     @classmethod
@@ -123,13 +125,13 @@ class ExecutorTaskMessage:
             return list(map(lambda m: m.encode(), executor_task_message_list))
 
     @classmethod
-    def create_message(cls, executor_message_list) -> str:
+    def create_message(cls, executor_message_list, task_groupid) -> str:
             """[summary]
 
             Returns:
                 str: [description]
             """
-            return list(map(lambda m: ExecutorTaskMessage(message=m, retry_count=0, driver_start_timestamp=timestamp()), executor_message_list))
+            return list(map(lambda m: ExecutorTaskMessage(message=m, retry_count=0, task_groupid=task_groupid, driver_start_timestamp=timestamp()), executor_message_list))
 
 
 class ExecutorResultStatusType(Enum):
@@ -145,6 +147,7 @@ class ExecutorResultMessage:
     driver_start_timestamp: str
     executor_start_timestamp: str
     retry_count: int
-    executor_id: int
+    trigger_groupid: str
+    task_groupid: str
     execute_time: str
     timestamp: str
\ No newline at end of file
